==> bonita-server-7.15.0-sources.jar: org/bonitasoft/engine/command/DeletePlatformSessionCommand.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.command;

import java.io.Serializable;
import java.util.Map;

import org.bonitasoft.engine.platform.session.PlatformSessionService;
import org.bonitasoft.engine.platform.session.SSessionNotFoundException;
import org.bonitasoft.engine.service.PlatformServiceAccessor;

/**
 * @author Charles Souillard
 */
public class DeletePlatformSessionCommand extends PlatformCommand {

    public Serializable execute(Map parameters, PlatformServiceAccessor serviceAccessor)
            throws SCommandParameterizationException, SCommandExecutionException {
        Long sessionId = (Long) parameters.get("sessionId");
        PlatformSessionService sessionService = serviceAccessor.getPlatformSessionService();
        try {
            sessionService.deleteSession(sessionId.longValue());
        } catch (SSessionNotFoundException e) {
            throw new SCommandExecutionException(e);
        }
        return null;
    }

}

==> bonita-server-9.0.0-sources.jar: org/bonitasoft/engine/command/DeletePlatformSessionCommand.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.command;

import java.io.Serializable;
import java.util.Map;

import org.bonitasoft.engine.platform.session.PlatformSessionService;
import org.bonitasoft.engine.platform.session.SSessionNotFoundException;
import org.bonitasoft.engine.service.ServiceAccessor;

/**
 * @author Charles Souillard
 */
public class DeletePlatformSessionCommand extends RuntimeCommand {

    public Serializable execute(Map parameters, ServiceAccessor serviceAccessor)
            throws SCommandParameterizationException, SCommandExecutionException {
        Long sessionId = (Long) parameters.get("sessionId");
        PlatformSessionService sessionService = serviceAccessor.getPlatformSessionService();
        try {
            sessionService.deleteSession(sessionId.longValue());
        } catch (SSessionNotFoundException e) {
            throw new SCommandExecutionException(e);
        }
        return null;
    }

}
